import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import React, { useEffect, useRef } from "react";

import {
	faMagnifyingGlassPlus,
	faMagnifyingGlassMinus,
	faPlus,
	faRemove,
	faArrowRotateLeft,
	faArrowRotateRight,
	faArrowsAltH,
	faArrowsAltV,
} from "@fortawesome/free-solid-svg-icons";
import { useState, useContext } from "react";
import Image from "./Image";

import ImagesContext from "../store/images-context";

const Container = ({ styles, classes, item }) => {
	const imageCTX = useContext(ImagesContext);

	const childRef = useRef();

	let _styles = styles || {};

	const [imageUrl, setImageUrl] = useState("");
	const [hasImage, setHasImage] = useState(false);
	const [grid, setGrid] = useState();

	/*eslint-disable no-undef*/

	// Create a new media frame
	const frame = wp.media({
		title: "Select or Upload Media",
		button: {
			text: "Use this media",
		},
		multiple: false, // Set to true to allow multiple files to be selected
	});
	/*eslint-enable no-undef*/

	classes = `${classes} image-container`;

	const handleZoomIn = () => {
		childRef.current.zoomIn();
	};

	const handleZoomOut = () => {
		childRef.current.zoomOut();
	};

	//adding image
	const imageUploadHandle = () => {
		if ("" !== imageUrl) {
			return;
		}

		if (frame) {
			frame.open();
			return;
		}

		// Finally, open the modal on click
		frame.open();
	};

	const imageRemoveHandler = () => {
		childRef.current.destroyImage();

		imageCTX.deleteImage({
			id: item.id,
		});
		setImageUrl("");
		setHasImage(false);
	};

	/*eslint-disable no-undef*/
	// Port selected image to canvas on selection
	frame.on("select", function () {
		// Get the attachment JSON and set the image source
		const attachment = frame.state().get("selection").first().toJSON();

		if (attachment.mime === "image/gif") {
			alert("GIFs cannot be added to image composites.");
			return false;
		}

		// Set image source
		if (attachment.sizes && typeof attachment.sizes.large !== "undefined") {
			// Use the large (1024w) image instead of full-size
			const wpImageUrl = attachment.sizes.large.url;
			imageCTX.addImage({
				id: item.id,
				image: wpImageUrl, //images[random] //Sample
				attachmentId: attachment.id
			});
		} else {
			const wpImageUrl = attachment.sizes.full.url;
			imageCTX.addImage({
				id: item.id,
				image: wpImageUrl, //images[random] //Sample
				attachmentId: attachment.id
			});
		}
	});

	/*eslint-enable no-undef*/

	const getActionClass = () => {
		return hasImage ? "actions" : "actions-single";
	};

	useEffect(() => {

		if (imageCTX.images.length === 0) {
			return;
		}

		const _img = imageCTX.getImage(item.id);
		if (typeof _img !== "undefined" && !hasImage) {
			setImageUrl(
				<Image
					src={_img.image}
					className="bg-image"
					ref={childRef}
					itemId={item.id}
				/>
			);

			setHasImage(true);
			setGrid(imageCTX.grid);
		}

		//re render the image when the grid changes
		if (imageUrl !== "" && grid !== imageCTX.grid) {
			childRef.current.reRender();
		}
	}, [imageCTX, grid, hasImage, imageUrl, item]);

	return (
		<div style={_styles} className={classes}>
			{imageUrl}

			<div className={getActionClass()}>
				{hasImage ? (
					<>
						<span
							className="icon"
							onClick={() => {
								childRef.current.scaleX();
							}}
						>
							<FontAwesomeIcon
								icon={faArrowsAltH}
								style={{ height: "30px" }}
							/>
						</span>

						<span
							className="icon"
							onClick={() => {
								childRef.current.scaleY();
							}}
						>
							<FontAwesomeIcon
								icon={faArrowsAltV}
								style={{ height: "30px" }}
							/>
						</span>

						<span
							className="icon"
							onClick={() => {
								childRef.current.rotateLeft();
							}}
						>
							<FontAwesomeIcon
								icon={faArrowRotateLeft}
								style={{ height: "30px" }}
							/>
						</span>

						<span
							className="icon"
							onClick={() => {
								childRef.current.rotateRight();
							}}
						>
							<FontAwesomeIcon
								icon={faArrowRotateRight}
								style={{ height: "30px" }}
							/>
						</span>

						<span className="icon" onClick={handleZoomIn}>
							<FontAwesomeIcon
								icon={faMagnifyingGlassPlus}
								style={{ height: "30px" }}
							/>
						</span>
						<span className="icon" onClick={handleZoomOut}>
							<FontAwesomeIcon
								icon={faMagnifyingGlassMinus}
								style={{ height: "30px" }}
							/>
						</span>
						<span className="icon" onClick={imageRemoveHandler}>
							<FontAwesomeIcon
								icon={faRemove}
								style={{ height: "30px" }}
							/>
						</span>
					</>
				) : (
					<span className="icon" onClick={imageUploadHandle}>
						<FontAwesomeIcon
							icon={faPlus}
							style={{ height: "30px" }}
						/>
					</span>
				)}
			</div>
		</div>
	);
};

export default Container;
