import React, {
	useEffect,
	useRef,
	forwardRef,
	useImperativeHandle,
} from "react";
import Cropper from "cropperjs";
import "../cropperjs/dist/cropper.min.css";

const Image = forwardRef(({ src, className, styles, itemId }, ref) => {
	const cropperRef = useRef(null);
	let cropper = null;

	useImperativeHandle(ref, () => ({
		destroyImage() {
			if (cropper) {
				cropper.destroy();
			}
		},

		zoomIn() {
			if (cropper) {
				cropper.zoom(0.1);
			} else {
				console.error('cropper not initialized');
			}
		},

		zoomOut() {
			if (cropper) {
				cropper.zoom(-0.1);
			} else {
				console.error('cropper not initialized');
			}
		},

		rotateLeft() {
			if (cropper) {
				cropper.rotate(-45);
			}
		},

		rotateRight() {
			if (cropper) {
				cropper.rotate(45);
			}
		},

		scaleY() {
			if (cropper) {
				cropper.scaleY(-1);
			}
		},

		scaleX() {
			if (cropper) {
				cropper.scaleX(-1);
			}
		},

		reRender() {
			cropper.destroy();
			cropper = new Cropper(cropperRef.current, {
				viewMode: 3,
				dragMode: "move",
				autoCropArea: 1,
				restore: false,
				modal: false,
				guides: false,
				highlight: false,
				cropBoxMovable: false,
				cropBoxResizable: false,
				toggleDragModeOnDblclick: false,
			});
		},
	}));

	useEffect(() => {
		if (src !== "") {
			const node = cropperRef.current;
			// eslint-disable-next-line react-hooks/exhaustive-deps
			cropper = new Cropper(node, {
				viewMode: 3,
				dragMode: "move",
				autoCropArea: 1,
				restore: false,
				modal: false,
				guides: false,
				highlight: false,
				cropBoxMovable: false,
				cropBoxResizable: false,
				toggleDragModeOnDblclick: false,
			});
		}
	}, []);

	return <img src={src} className={className} ref={cropperRef} alt="Preview" />;
});

export default Image;
