import React, {
	useState,
	useEffect,
	useContext,
} from "react";
import { layouts } from "../utills";
import LayoutItem from "./LayoutItem";
import LayoutRowItem from "./LayoutRowItem";
import { layoutFormat } from "../utills";
import ImagesContext from "../store/images-context";

const Select = ({ setLayout, setLayoutFormat }) => {
	const [layoutName, setLayoutName] = useState("single");
	const [layoutFormatName, setLayoutFormatName] = useState("sixteen-by-nine");

	const imageContext = useContext(ImagesContext);

	const menuLayout = [];

	const getClasses = (key) => {
		const selected = key === layoutName ? "selected" : "";
		return `menu-item ${selected}`;
	};

	const getFormatClasses = (key) => {
		const selected = key === layoutFormatName ? "selected" : "";
		return `menu-item ${selected}`;
	};

	const handleLayoutElement = (event) => {
		const selected = event.currentTarget.dataset.name;
		setLayoutName(selected);
		for (const [key, value] of Object.entries(layouts)) {
			if (key === selected) {
				setLayout(value);
				imageContext.setGrid(key);
				return;
			}
		}
	};

	const handleLayoutFormateElement = (event) => {
		const selected = event.currentTarget.dataset.name;
		setLayoutFormatName(selected);
		for (const [value] of Object.entries(layoutFormat)) {
			if (value.class === selected) {
				setLayoutFormat(value);
				imageContext.addLayoutFormat(value);
				return;
			}
		}
	};

	for (const [key, value] of Object.entries(layouts)) {
		let cols_css = {
			gridTemplateColumns: "",
			display: "grid",
			width: "100%",
			height: "100%",
			border: "1px solid black",
		};

		if (value.cols.length > 0) {
			value.cols.forEach((item) => {
				cols_css.gridTemplateColumns += ` ${item.width}%`;
			});
		}

		menuLayout.push(
			<li
				className={getClasses(key)}
				key={key}
				data-name={key}
				onClick={handleLayoutElement}
			>
				<div style={cols_css}>
					{value.cols.map((item, key) => {
						if (Array.isArray(item.height)) {
							return (
								<div
									className="inner-grid"
									key={item.id}
									style={{ rowGap: "0px" }}
								>
									<LayoutRowItem layout={item.height} />
								</div>
							);
						}

						const style = {
							height: `100%`,
						};
						return (
							<LayoutItem
								styles={style}
								key={item.id}
								classes=""
								item={item}
							/>
						);
					})}
				</div>
			</li>
		);
	}

	useEffect(() => {
		//setLayout("single");
	}, []);

	return (
		<div className="layout-selection">
			<ul>{menuLayout}</ul>

			<ul>
				{layoutFormat.map((item, key) => {
					return (
						<li
							className={getFormatClasses(item.class)}
							key={key}
							data-name={item.class}
							onClick={handleLayoutFormateElement}
						>
							<LayoutItem
								styles={{
									height: `100%`,
									textAlign: "center",
								}}
								classes=""
								item={item}
							>
								<span>{item.name}</span>
							</LayoutItem>
						</li>
					);
				})}
			</ul>
		</div>
	);
};

export default Select;
