import { createContext, useState } from "react";

const ImagesContext = createContext({
	images: [],
	layoutFormat: {
		name: "16:9",
		class: "sixteen-by-nine",
		height: 562,
		width: 1000,
	},
	lockImage: false,
	grid: "single",

	addImage: (imagePath) => { },
	getImage: (id) => { },
	updateImage: (data) => { },
	deleteImage: (data) => { },
	addLayoutFormat: (layout) => { },
	getLayoutFormat: () => { },
	setLockImage: (lock) => { },
	setGrid: (grid) => { },
});

export const ImagesContextProvider = (props) => {
	const [images, setImages] = useState([]);
	const [layout, setLayout] = useState({});
	const [lockImage, setLockImage] = useState(false);
	const [grid, setGrid] = useState("single");

	const addImageHandler = (data) => {
		setImages((prev) => {
			const currentValue = prev.concat(data);
			return currentValue;
		});
	};

	const updateImageHandler = (data) => {
		setImages((prev) => {
			const currentValue = prev.map((item) => {
				if (item.id === data.id) {
					return data;
				}
				return item;
			});
			return currentValue;
		});
	};

	const deleteImageHandler = (data) => {
		const filtered = images.filter((item) => {
			return item.id !== data.id;
		});
		setImages(filtered);
	};

	const getImageHandler = (id) => {
		const image = images.find((item) => item.id === id);
		return image;
	};

	const addLayoutHandler = (_layout) => {
		setLayout(_layout);
	};

	const getLayoutHandler = () => {
		return layout;
	};

	const context = {
		images: images,
		layoutFormat: layout,
		lockImage: lockImage,
		grid: grid,
		addImage: addImageHandler,
		getImage: getImageHandler,
		updateImage: updateImageHandler,
		deleteImage: deleteImageHandler,

		addLayoutFormat: addLayoutHandler,
		getLayoutFormat: getLayoutHandler,
		setLockImage: (lock) => {
			setLockImage(lock);
		},

		setGrid: (grid) => {
			setGrid(grid);
		},
	};

	return (
		<ImagesContext.Provider value={context}>
			{props.children}
		</ImagesContext.Provider>
	);
};

export default ImagesContext;
